# i-MongoDB

This is a standardized and customized connector to MongoDB.

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Prerequisites

This package supports the following version of Python. It probably supports older versions, but they have not been tested.

- Python 3.10 or later

### Installing

Install the latest package using pip.

```bash
$ pip install i-mongodb
```

End with an example of getting some data out of the system or using it for a little demo

## Running the tests

Explain how to run the automated tests for this system

```bash
$ python -m pytest
```

## Usage

TODO

## Authors

- **Jason Romano** - [Aracnid](https://github.com/aracnid)

See also the list of [contributors](https://github.com/aracnid/i-mongodb/contributors) who participated in this project.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details
